@@ -64,8 +64,6 @@ from fabric.api import lcd
 
 PROJECTS = []
 
-
-
 class RstFile(object):
     def __init__(self,local_root,url_root,parts):
         self.path = local_root.child(*parts)
@@ -81,8 +79,14 @@ class Project(object):
         self.dist = pkg_resources.get_distribution(name)
         self.module = __import__(name)
     
+def load_projects():
+    if len(PROJECTS) > 0: 
+        return 
+    for i,prj in enumerate(env.projects.split()):
+        PROJECTS.append(Project(i,prj))
+      
 
-def setup_from_project(main_package):
+def setup_from_project(main_package=None):
   
     #~ env.docs_rsync_dest = 'luc@lino-framework.org'
     #~ env.sdist_dir = '../lino/docs/dl'
@@ -91,9 +95,6 @@ def setup_from_project(main_package):
     #~ REMOTE = AttrDict(
       #~ lf='lino-framework.org')
       
-    for i,prj in enumerate(env.projects.split()):
-        PROJECTS.append(Project(i,prj))
-      
     env.ROOTDIR = Path().absolute()
 
     env.project_name = env.ROOTDIR.absolute().name
@@ -107,10 +108,12 @@ def setup_from_project(main_package):
     env.bash_tests = []
     env.django_databases = []
     env.simple_doctests = []
+    env.docs_doctests = []
     env.main_package = main_package
     env.tolerate_sphinx_warnings = False
 
-
+    env.languages = None
+    
     #~ print env.project_name
 
     env.DOCSDIR = Path(env.ROOTDIR,'docs')
@@ -119,9 +122,12 @@ def setup_from_project(main_package):
     if not env.DOCSDIR.exists():
         raise Exception("You must call 'fab' from a project's root directory.")
         
+    if env.main_package:
+        execfile(env.ROOTDIR.child(env.main_package,'setup_info.py'),globals()) # will set SETUP_INFO 
+        env.SETUP_INFO = SETUP_INFO
+    else:
+        env.SETUP_INFO = None
         
-    execfile(env.ROOTDIR.child(env.main_package,'setup_info.py'),globals()) # will set SETUP_INFO 
-    env.SETUP_INFO = SETUP_INFO
     
 
 
@@ -154,18 +160,117 @@ def rmtree_after_confirm(p):
     p.rmtree()
     
 
+
+def get_locale_dir():
+    if not env.main_package:
+        abort("No main_package")
+    p = env.ROOTDIR.child(env.main_package,"locale")
+    if not p.isdir():
+        abort("Directory %s does not exist." % p)
+    return p
+
+@task(alias='em')
+def extract_messages():
+    """Extract messages from source files to .pot file"""
+    locale_dir = get_locale_dir()
+    args = ["python", "setup.py"]
+    args += [ "extract_messages"]
+    args += [ "-o", locale_dir.child("django.pot")]
+    cmd = ' '.join(args)
+    #~ must_confirm(cmd)
+    local(cmd)
+    
+@task(alias='emd')
+def extract_messages_docs(): 
+    """
+    Run the Sphinx gettext builder on userdocs.
+    """
+    args = ['sphinx-build','-b','gettext']
+    userdocs = env.ROOTDIR.child('userdocs')
+    if not userdocs.isdir():
+        abort("Directory %s does not exist." % userdocs)
+    #~ args += cmdline_args
+    #~ args += ['-a'] # all files, not only outdated
+    #~ args += ['-P'] # no postmortem
+    #~ args += ['-Q'] # no output
+    if not env.tolerate_sphinx_warnings:
+        args += ['-W'] # consider warnings as errors
+    #~ args += ['-w',env.DOCSDIR.child('warnings.txt')]
+    args += [userdocs]
+    args += [userdocs.child("translations")]
+    #~ args += [env.DOCSDIR,env.BUILDDIR]
+    #~ sphinx.main(args)
+    #~ sphinx.main(args)
+    cmd = ' '.join(args)
+    local(cmd)
+    
+    
+
+@task(alias='im')
+def init_catalog():
+    """Create .po files if necessary."""
+    locale_dir = get_locale_dir()
+    for loc in env.languages:
+        f = locale_dir.child(loc,'LC_MESSAGES','django.po')
+        if f.exists():
+            print "Skip %s because file exists." % f
+        else:
+            args = ["python", "setup.py"]
+            args += [ "init_catalog"]
+            args += [ "--domain django"]
+            args += [ "-d" , locale_dir ]
+            args += [ "-l" , loc ]
+            cmd = ' '.join(args)
+            must_confirm(cmd)
+            local(cmd)
+
+
+
+@task(alias='um')
+def update_catalog():
+    """Update .po files from .pot file."""
+    locale_dir = get_locale_dir()
+    for loc in env.languages:
+        args = ["python", "setup.py"]
+        args += [ "update_catalog"]
+        args += [ "--domain django"]
+        args += [ "-d" , locale_dir ]
+        args += [ "-i", locale_dir.child("django.pot")]
+        args += [ "-l" , loc ]
+        cmd = ' '.join(args)
+        #~ must_confirm(cmd)
+        local(cmd)
+
+@task(alias='cm')
+def compile_catalog():
+    """Compile .po files to .mo files."""
+    locale_dir = get_locale_dir()
+    for loc in env.languages:
+        args = ["python", "setup.py"]
+        args += [ "compile_catalog"]
+        args += [ "--domain django"]
+        args += [ "-d" , locale_dir ]
+        args += [ "-l" , loc ]
+        cmd = ' '.join(args)
+        #~ must_confirm(cmd)
+        local(cmd)
+
+
+
+
 @task(alias='summary')
 def summary(*cmdline_args):
+    """Print a summary to stdout."""
+    load_projects()
     headers = (
       #~ '#','Location',
       'Project','Old version','New version')
 
     def cells(self):
+        url = self.module.SETUP_INFO['url']
         desc = "`%s <%s>`__ -- %s" % (
-            self.name,
-            self.module.SETUP_INFO['url'],
-            self.module.SETUP_INFO['description'],
-            )        
+            self.name,url,
+            self.module.SETUP_INFO['description'])
         return (
             '\n'.join(textwrap.wrap(desc,40)),
             self.dist.version,
@@ -198,13 +303,15 @@ def build_api(*cmdline_args):
     local(cmd)
     
   
+    
 @task(alias='html')
 def build_html(): #~ def build_html(*cmdline_args):
     """
     write_readme + build sphinx html docs.
     """
-    write_readme()
-    write_release_notes()
+    if env.main_package:
+        write_readme()
+        write_release_notes()
     #~ print cmdline_args
     args = ['sphinx-build','-b','html']
     #~ args += cmdline_args
@@ -481,23 +588,23 @@ def write_release_notes():
     """
     Generate docs/releases/x.y.z.rst file from setup_info.
     """
-    notes = Path(env.ROOTDIR,'docs','releases','%s.rst' % env.SETUP_INFO['version'])
+    v = env.SETUP_INFO['version']
+    if v.endswith('+'):
+        return
+    notes = Path(env.ROOTDIR,'docs','releases','%s.rst' % v)
     if notes.exists():
         return
     must_confirm("Create %s" % notes.absolute())
-    context = dict(date=datetime.date.today().strftime(env.long_date_format))
+    #~ context = dict(date=datetime.date.today().strftime(env.long_date_format))
+    context = dict(date=datetime.date.today().strftime('%Y%m%d'))
     context.update(env.SETUP_INFO)
     txt = """\
 ==========================
 Version %(version)s
 ==========================
 
-%(date)s
+Release process started :blogref:`%(date)s`
 
-I am pleased to announce the release of 
-version %(version)s of `%(name)s <%(url)s>`__.
-
-%(author)s
 
 List of changes
 ===============
@@ -577,7 +684,7 @@ def run_django_doctests():
         #~ cmd = "python runtest.py %s" % prj
         local(cmd)
 
-@task(alias='t4')
+@task(alias='t1')
 def run_simple_doctests():
     """
     Run a simple doctest for files specified in `env.simple_doctests`.
@@ -589,12 +696,29 @@ def run_simple_doctests():
         local(cmd)
         #~ doctest.testfile(filename, module_relative=False,encoding='utf-8')
 
+@task(alias='t4')
+def run_docs_doctests():
+    """
+    Run a simple doctest for files specified in `env.docs_doctests`.
+    """
+    os.environ['DJANGO_SETTINGS_MODULE']='settings'
+    #~ with lcd(env.DOCSDIR):
+    env.DOCSDIR.chdir()
+    sys.path.insert(0,'.')
+    for filename in env.docs_doctests:
+        #~ cmd = "python -m doctest %s" % filename
+        #~ print cmd
+        #~ local(cmd)
+        #~ fn = env.DOCSDIR.child(*filename.split('/'))
+        doctest.testfile(filename, module_relative=False,encoding='utf-8')
+    del sys.path[0]
+
 @task(alias='t5')
 def run_django_databases_tests():    
     """
     Run "manage.py test" for each `env.django_databases`.
     """
-    run_in_django_databases('test',"--noinput")
+    run_in_django_databases('test',"--noinput",'--failfast')
 
 @task(alias='t6')
 def run_setup_tests():    
