@@ -223,7 +223,7 @@ class Py2rstDirective(InsertInputDirective):
         sys.stdout = buffer
         context = dict()
         from django.conf import settings
-        #~ context = dict(settings=settings)
+        context = dict(settings=settings)
         context.update(settings.SITE.modules)
         context.update(self=self)
         context.update(env=self.state.document.settings.env)
@@ -452,7 +452,7 @@ class YearBlogIndexDirective(InsertInputDirective):
     
       
     def get_rst(self):
-        from north import dbutils
+        from djangosite.dbutils import monthname
   
         #~ year = self.arguments[0]
         env = self.state.document.settings.env
@@ -473,7 +473,7 @@ class YearBlogIndexDirective(InsertInputDirective):
             
             text += """        
             
-.. |M%02d| replace::  **%s**""" % (month,dbutils.monthname(month))
+.. |M%02d| replace::  **%s**""" % (month,monthname(month))
             
             weeknum = None
             #~ text += "\n  |br| Mo Tu We Th Fr Sa Su "
@@ -612,12 +612,13 @@ def configure(filename,globals_dict):
     HGWORK = DOCSDIR.ancestor(2)
     intersphinx_mapping = dict()
     for n in ('site','north','lino','welfare'):
+    #~ for n in ('site','north','welfare'):
         p = Path(HGWORK,n,'docs','.build','objects.inv')
         if p.exists():
             intersphinx_mapping[n] = ('http://%s.lino-framework.org' % n,p)
-    intersphinx_mapping.update(django = (
-        'http://docs.djangoproject.com/en/dev/', 
-        'http://docs.djangoproject.com/en/dev/_objects/'))
+    #~ intersphinx_mapping.update(django = (
+        #~ 'http://docs.djangoproject.com/en/dev/', 
+        #~ 'http://docs.djangoproject.com/en/dev/_objects/'))
     globals_dict.update(intersphinx_mapping=intersphinx_mapping)
     
     globals_dict.update(extensions = [
@@ -628,7 +629,8 @@ def configure(filename,globals_dict):
       'sphinx.ext.extlinks',
       'sphinx.ext.graphviz',
       'sphinx.ext.intersphinx',
-      'sphinx.ext.doctest',
+      'sphinxcontrib.newsfeed', # no i18n, no discovery, only one entry per doc, 
+      #~ 'sphinx.ext.doctest',
     ])
     
     #~ os.environ['DJANGO_SETTINGS_MODULE'] = 'north.docs_settings'
@@ -701,8 +703,9 @@ def version2rst(self,m):
     if v.endswith('+'):
         v = v[:-1]
         print "The current stable release is :doc:`%s`." % v 
+        print "We are working on a future version in the code repository."
     elif v.endswith('pre'):
-        print "We're currently working on  :doc:`%s`." % v[:-3]
+        print "We're currently working on :doc:`%s`." % v[:-3]
     else:
         print "The current stable release is :doc:`%s`." % v 
         #~ print "We're currently working on :doc:`coming`."
